from .individu import get_data_individu
from .pekerjaan import get_data_pekerjaan
from .penghasilan import get_data_penghasilan
from .kesehatan import get_data_kesehatan
from .disabilitas import get_data_disabilitas
from .pendidikan import get_data_pendidikan


__all__ = [
    "get_data_individu",
    "get_data_pekerjaan",
    "get_data_penghasilan",
    "get_data_kesehatan",
    "get_data_disabilitas",
    "get_data_pendidikan",
]
